@@ -37,6 +37,8 @@ yum install -y \
         openstack-tripleo-puppet-elements \
         openvswitch \
         os-net-config \
+        dhclient \
+        ethtool \
         python-heat-agent-apply-config \
         python-heat-agent-hiera \
         python-heat-agent-puppet \
@@ -51,13 +53,8 @@ yum install -y \
 yum install -y --downloadonly --downloaddir=/tmp/packages \
         libvirt-daemon-config-nwfilter \
         libvirt-daemon-kvm \
-        openstack-ceilometer-compute \
-        openstack-neutron \
-        openstack-neutron-ml2 \
-        openstack-neutron-openvswitch \
-        openstack-nova-common \
-        openstack-nova-compute \
-        python-nova
+        python-nova \
+        openstack-*
 
 CUR=$(pwd)
 cd /tmp/packages
@@ -82,7 +79,9 @@ ln -sf /usr/share/tripleo-puppet-elements/hiera/os-apply-config/etc/puppet/hiera
 ln -sf /etc/puppet/hiera.yaml /etc/hiera.yaml
 
 # Configure os-*
-ln -sf /usr/share/tripleo-puppet-elements/hiera/os-refresh-config/configure.d/40-hiera-datafiles \
+ln -sf /usr/share/tripleo-puppet-elements/hiera/40-hiera-datafiles \
+    /usr/libexec/os-refresh-config/configure.d/
+ln -sf /usr/share/tripleo-puppet-elements/hiera/10-hiera-disable \
     /usr/libexec/os-refresh-config/configure.d/
 mkdir -p /usr/libexec/os-refresh-config/post-configure.d
 ln -sf /usr/share/tripleo-image-elements/os-refresh-config/os-refresh-config/post-configure.d/99-refresh-completed \
