@@ -27,7 +27,7 @@ from tripleo_common.tests.utils import test_validations
 class GetPubkeyActionTest(base.TestCase):
 
     @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_workflow_client')
+        'tripleo_common.actions.base.TripleOAction.get_workflow_client')
     def test_run_existing_pubkey(self, get_workflow_client_mock):
         mistral = mock.MagicMock()
         get_workflow_client_mock.return_value = mistral
@@ -39,26 +39,33 @@ class GetPubkeyActionTest(base.TestCase):
         self.assertEqual('existing_pubkey', action.run())
 
     @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_workflow_client')
-    @mock.patch('tripleo_common.utils.passwords.create_ssh_keypair')
-    def test_run_no_pubkey(self, mock_create_keypair,
-                           get_workflow_client_mock):
+        'tripleo_common.actions.base.TripleOAction.get_workflow_client')
+    @mock.patch('tripleo_common.utils.validations.create_ssh_keypair')
+    @mock.patch('tempfile.mkdtemp')
+    @mock.patch('shutil.rmtree')
+    def test_run_no_pubkey(self, mock_rmtree, mock_mkdtemp,
+                           mock_create_keypair, get_workflow_client_mock):
         mistral = mock.MagicMock()
         get_workflow_client_mock.return_value = mistral
         mistral.environments.get.side_effect = 'nope, sorry'
-        mock_create_keypair.return_value = {
-            'public_key': 'public_key',
-            'private_key': 'private_key',
-        }
+        mock_mkdtemp.return_value = '/tmp_path'
 
-        action = validations.GetPubkeyAction()
-        self.assertEqual('public_key', action.run())
+        mock_open_context = mock.mock_open()
+        mock_open_context().read.side_effect = ['private_key', 'public_key']
+
+        with mock.patch('six.moves.builtins.open', mock_open_context):
+            action = validations.GetPubkeyAction()
+            self.assertEqual('public_key', action.run())
+
+        mock_mkdtemp.assert_called_once()
+        mock_create_keypair.assert_called_once_with('/tmp_path/id_rsa')
+        mock_rmtree.asser_called_once_with('/tmp_path')
 
 
 class Enabled(base.TestCase):
 
     @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_workflow_client')
+        'tripleo_common.actions.base.TripleOAction.get_workflow_client')
     def test_validations_enabled(self, get_workflow_client_mock):
         mistral = mock.MagicMock()
         get_workflow_client_mock.return_value = mistral
@@ -68,7 +75,7 @@ class Enabled(base.TestCase):
         self.assertEqual(result, True)
 
     @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_workflow_client')
+        'tripleo_common.actions.base.TripleOAction.get_workflow_client')
     def test_validations_disabled(self, get_workflow_client_mock):
         mistral = mock.MagicMock()
         get_workflow_client_mock.return_value = mistral
@@ -80,7 +87,7 @@ class Enabled(base.TestCase):
     @mock.patch(
         'tripleo_common.actions.validations.Enabled._validations_enabled')
     @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_workflow_client')
+        'tripleo_common.actions.base.TripleOAction.get_workflow_client')
     def test_success_with_validations_enabled(self, get_workflow_client_mock,
                                               validations_enabled_mock):
         validations_enabled_mock.return_value = True
@@ -93,7 +100,7 @@ class Enabled(base.TestCase):
     @mock.patch(
         'tripleo_common.actions.validations.Enabled._validations_enabled')
     @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_workflow_client')
+        'tripleo_common.actions.base.TripleOAction.get_workflow_client')
     def test_success_with_validations_disabled(self, get_workflow_client_mock,
                                                validations_enabled_mock):
         validations_enabled_mock.return_value = False
@@ -139,7 +146,7 @@ class ListGroupsActionTest(base.TestCase):
 class RunValidationActionTest(base.TestCase):
 
     @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_workflow_client')
+        'tripleo_common.actions.base.TripleOAction.get_workflow_client')
     @mock.patch('tripleo_common.utils.validations.write_identity_file')
     @mock.patch('tripleo_common.utils.validations.cleanup_identity_file')
     @mock.patch('tripleo_common.utils.validations.run_validation')
@@ -170,7 +177,7 @@ class RunValidationActionTest(base.TestCase):
             'identity_file_path')
 
     @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_workflow_client')
+        'tripleo_common.actions.base.TripleOAction.get_workflow_client')
     @mock.patch('tripleo_common.utils.validations.write_identity_file')
     @mock.patch('tripleo_common.utils.validations.cleanup_identity_file')
     @mock.patch('tripleo_common.utils.validations.run_validation')
