@@ -15,7 +15,6 @@
 import base64
 import logging
 import os
-import paramiko
 import struct
 import time
 import uuid
@@ -40,6 +39,7 @@ def generate_overcloud_passwords(mistralclient, stack_env=None):
     passwords = {}
 
     for name in constants.PASSWORD_PARAMETER_NAMES:
+
         # Support users upgrading from Mitaka or otherwise creating a plan for
         # a Heat stack that already exists.
         if stack_env and name in stack_env.get('parameter_defaults', {}):
@@ -54,10 +54,9 @@ def generate_overcloud_passwords(mistralclient, stack_env=None):
         # The SnmpdReadonlyUserPassword is stored in a mistral env.
         elif name == 'SnmpdReadonlyUserPassword':
             passwords[name] = get_snmpd_readonly_user_password(mistralclient)
-        elif name in ('KeystoneCredential0', 'KeystoneCredential1'):
+        elif name in ('KeystoneCredential0', 'KeystoneCredential1',
+                      'KeystoneFernetKey0', 'KeystoneFernetKey1'):
             passwords[name] = create_keystone_credential()
-        elif name == 'MigrationSshKey':
-            passwords[name] = create_ssh_keypair()
         else:
             passwords[name] = passutils.generate_password(
                 size=_MIN_PASSWORD_SIZE)
@@ -83,18 +82,3 @@ def get_snmpd_readonly_user_password(mistralclient):
 
 def create_keystone_credential():
     return base64.urlsafe_b64encode(os.urandom(32))
-
-
-def create_ssh_keypair(comment=None, bits=2048):
-    """Generate an ssh keypair for use on the overcloud"""
-    if comment is None:
-        comment = "Generated by TripleO"
-    key = paramiko.RSAKey.generate(bits)
-    keyout = six.StringIO()
-    key.write_private_key(keyout)
-    private_key = keyout.getvalue()
-    public_key = '{} {} {}'.format(key.get_name(), key.get_base64(), comment)
-    return {
-        'private_key': private_key,
-        'public_key': public_key,
-    }
